@@ -225,7 +225,10 @@ func UpdateRevisionTemplateAnnotation(template *servingv1.RevisionTemplateSpec,
 	// without changing the existing spec
 	in := make(map[string]string)
 	in[annotation] = value
-	if err := autoscaling.ValidateAnnotations(in); err != nil {
+	// The boolean indicates whether or not the init-scale annotation can be set to 0.
+	// Since we don't have the config handy, err towards allowing it. The API will
+	// correctly fail the request if it's forbidden.
+	if err := autoscaling.ValidateAnnotations(true, in); err != nil {
 		return err
 	}
 
@@ -302,8 +305,8 @@ func FreezeImageToDigest(template *servingv1.RevisionTemplateSpec, baseRevision
 		return fmt.Errorf("could not freeze image to digest since current revision contains unexpected image")
 	}
 
-	if baseRevision.Status.ImageDigest != "" {
-		return UpdateImage(template, baseRevision.Status.ImageDigest)
+	if baseRevision.Status.DeprecatedImageDigest != "" {
+		return UpdateImage(template, baseRevision.Status.DeprecatedImageDigest)
 	}
 	return nil
 }
@@ -352,8 +355,42 @@ func UpdateUser(template *servingv1.RevisionTemplateSpec, user int64) error {
 	return nil
 }
 
-// UpdateResources updates resources as requested
-func UpdateResources(template *servingv1.RevisionTemplateSpec, requestsResourceList corev1.ResourceList, limitsResourceList corev1.ResourceList) error {
+// UpdateResources updates container resources for given revision template
+func UpdateResources(template *servingv1.RevisionTemplateSpec, resources corev1.ResourceRequirements, requestsToRemove, limitsToRemove []string) error {
+	container, err := ContainerOfRevisionTemplate(template)
+	if err != nil {
+		return err
+	}
+
+	if container.Resources.Requests == nil {
+		container.Resources.Requests = corev1.ResourceList{}
+	}
+
+	for k, v := range resources.Requests {
+		container.Resources.Requests[k] = v
+	}
+
+	for _, reqToRemove := range requestsToRemove {
+		delete(container.Resources.Requests, corev1.ResourceName(reqToRemove))
+	}
+
+	if container.Resources.Limits == nil {
+		container.Resources.Limits = corev1.ResourceList{}
+	}
+
+	for k, v := range resources.Limits {
+		container.Resources.Limits[k] = v
+	}
+
+	for _, limToRemove := range limitsToRemove {
+		delete(container.Resources.Limits, corev1.ResourceName(limToRemove))
+	}
+
+	return nil
+}
+
+// UpdateResourcesDeprecated updates resources as requested
+func UpdateResourcesDeprecated(template *servingv1.RevisionTemplateSpec, requestsResourceList corev1.ResourceList, limitsResourceList corev1.ResourceList) error {
 	container, err := ContainerOfRevisionTemplate(template)
 	if err != nil {
 		return err
