@@ -26,11 +26,10 @@ import (
 	"testing"
 
 	"gotest.tools/assert"
+	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 
 	"knative.dev/client/lib/test"
 	"knative.dev/client/pkg/util"
-
-	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 )
 
 func TestServiceOptions(t *testing.T) {
@@ -52,7 +51,7 @@ func TestServiceOptions(t *testing.T) {
 	validateServiceConcurrencyUtilization(r, "svc1", "50")
 
 	t.Log("update and validate service with concurrency limit")
-	serviceUpdate(r, "svc1", "--concurrency-limit", "300")
+	test.ServiceUpdate(r, "svc1", "--concurrency-limit", "300")
 	validateServiceConcurrencyLimit(r, "svc1", "300")
 
 	t.Log("update concurrency options with invalid values for service")
@@ -66,7 +65,7 @@ func TestServiceOptions(t *testing.T) {
 	validateServiceConcurrencyUtilization(r, "svc1", "50")
 
 	t.Log("delete service")
-	serviceDelete(r, "svc1")
+	test.ServiceDelete(r, "svc1")
 
 	t.Log("create and validate service with min/max scale options ")
 	serviceCreateWithOptions(r, "svc2", "--min-scale", "1", "--max-scale", "3")
@@ -74,39 +73,39 @@ func TestServiceOptions(t *testing.T) {
 	validateServiceMaxScale(r, "svc2", "3")
 
 	t.Log("update and validate service with max scale option")
-	serviceUpdate(r, "svc2", "--max-scale", "2")
+	test.ServiceUpdate(r, "svc2", "--max-scale", "2")
 	validateServiceMaxScale(r, "svc2", "2")
 
 	t.Log("delete service")
-	serviceDelete(r, "svc2")
+	test.ServiceDelete(r, "svc2")
 
 	t.Log("create, update and validate service with annotations")
 	serviceCreateWithOptions(r, "svc3", "--annotation", "alpha=wolf", "--annotation", "brave=horse")
 	validateServiceAnnotations(r, "svc3", map[string]string{"alpha": "wolf", "brave": "horse"})
-	serviceUpdate(r, "svc3", "--annotation", "alpha=direwolf", "--annotation", "brave-")
+	test.ServiceUpdate(r, "svc3", "--annotation", "alpha=direwolf", "--annotation", "brave-")
 	validateServiceAnnotations(r, "svc3", map[string]string{"alpha": "direwolf", "brave": ""})
-	serviceDelete(r, "svc3")
+	test.ServiceDelete(r, "svc3")
 
 	t.Log("create, update and validate service with annotations but -a")
 	serviceCreateWithOptions(r, "svc3a", "-a", "alpha=wolf", "-a", "brave=horse")
 	validateServiceAnnotations(r, "svc3a", map[string]string{"alpha": "wolf", "brave": "horse"})
-	serviceUpdate(r, "svc3a", "-a", "alpha=direwolf", "-a", "brave-")
+	test.ServiceUpdate(r, "svc3a", "-a", "alpha=direwolf", "-a", "brave-")
 	validateServiceAnnotations(r, "svc3a", map[string]string{"alpha": "direwolf", "brave": ""})
-	serviceDelete(r, "svc3a")
+	test.ServiceDelete(r, "svc3a")
 
 	t.Log("create, update and validate service with autoscale window option")
 	serviceCreateWithOptions(r, "svc4", "--autoscale-window", "1m")
 	validateAutoscaleWindow(r, "svc4", "1m")
-	serviceUpdate(r, "svc4", "--autoscale-window", "15s")
+	test.ServiceUpdate(r, "svc4", "--autoscale-window", "15s")
 	validateAutoscaleWindow(r, "svc4", "15s")
-	serviceDelete(r, "svc4")
+	test.ServiceDelete(r, "svc4")
 
 	t.Log("create, update and validate service with cmd and arg options")
 	serviceCreateWithOptions(r, "svc5", "--cmd", "/go/bin/helloworld")
 	validateContainerField(r, "svc5", "command", "[/go/bin/helloworld]")
-	serviceUpdate(r, "svc5", "--arg", "myArg1", "--arg", "--myArg2")
+	test.ServiceUpdate(r, "svc5", "--arg", "myArg1", "--arg", "--myArg2")
 	validateContainerField(r, "svc5", "args", "[myArg1 --myArg2]")
-	serviceUpdate(r, "svc5", "--arg", "myArg1")
+	test.ServiceUpdate(r, "svc5", "--arg", "myArg1")
 	validateContainerField(r, "svc5", "args", "[myArg1]")
 
 	t.Log("create, update and validate service with user defined")
@@ -118,12 +117,16 @@ func TestServiceOptions(t *testing.T) {
 
 	serviceCreateWithOptions(r, "svc6", "--user", strconv.FormatInt(uid, 10))
 	validateUserID(r, "svc6", uid)
-	serviceUpdate(r, "svc6", "--user", strconv.FormatInt(uid+1, 10))
+	test.ServiceUpdate(r, "svc6", "--user", strconv.FormatInt(uid+1, 10))
 	validateUserID(r, "svc6", uid+1)
 
 	t.Log("create and validate service and revision labels")
 	serviceCreateWithOptions(r, "svc7", "--label-service", "svc=helloworld-svc", "--label-revision", "rev=helloworld-rev")
 	validateLabels(r, "svc7", map[string]string{"svc": "helloworld-svc"}, map[string]string{"rev": "helloworld-rev"})
+
+	t.Log("create and validate service resource options")
+	serviceCreateWithOptions(r, "svc8", "--limit", "memory=500Mi,cpu=1000m", "--request", "memory=250Mi,cpu=200m")
+	test.ValidateServiceResources(r, "svc8", "250Mi", "200m", "500Mi", "1000m")
 }
 
 func serviceCreateWithOptions(r *test.KnRunResultCollector, serviceName string, options ...string) {
